@@ -85,7 +85,7 @@
 
 // Type indices
 enum : int {
-    SBK_QSQL_IDX                                             = 1,
+    SBK_QtSqlQSQL_IDX                                        = 1,
     SBK_QSQL_LOCATION_IDX                                    = 2,
     SBK_QSQL_PARAMTYPEFLAG_IDX                               = 4,
     SBK_QFLAGS_QSQL_PARAMTYPEFLAG_IDX                        = 0,
